==> tiny-swagger-0.0.1-20181228.101223-1-sources.jar: com/gymchina/tiny/swagger/SwaggerRegisterConfiguration.java <==
package com.gymchina.tiny.swagger;

import java.io.IOException;
import java.net.URISyntaxException;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.context.annotation.Bean;

import com.google.common.base.Predicate;
import com.google.common.base.Predicates;

import springfox.documentation.builders.ApiInfoBuilder;
import springfox.documentation.builders.PathSelectors;
import springfox.documentation.service.ApiInfo;
import springfox.documentation.service.Contact;
import springfox.documentation.spi.DocumentationType;
import springfox.documentation.spring.web.plugins.Docket;
import springfox.documentation.swagger2.annotations.EnableSwagger2;

/**
 * @Title SwaggerRegisterConfiguration
 * @Package com.gymchina.tiny.swagger
 * @author tangjunfeng
 * @date 2018年12月28日 下午4:15:21
 * @version V1.0
 */
@EnableSwagger2
public abstract class SwaggerRegisterConfiguration {

	private static Logger logger = LoggerFactory.getLogger(SwaggerRegisterConfiguration.class);

	@Bean
	public Docket petApi() throws ClassNotFoundException, IOException, URISyntaxException {
		logger.info("Loadding Swagger Interfaces Infomation [Title : {} , creater : {}]", title(), creater());
		return new Docket(DocumentationType.SWAGGER_2).groupName("full-api").apiInfo(apiInfo()).select()
				.paths(petstorePaths()).build().useDefaultResponseMessages(false);
	}

	public abstract String[] swaggerPackages();

	@SuppressWarnings("unchecked")
	public Predicate<String> petstorePaths() throws ClassNotFoundException, IOException, URISyntaxException {
		List<String> urls = DiscoverySwagger.discoveryMappingUrl(swaggerPackages());
		if (null == urls || urls.isEmpty())
			return Predicates.or();
		Predicate<String>[] predicates = new Predicate[urls.size()];
		for (int i = 0; i < urls.size(); i++) {
			predicates[i] = PathSelectors.regex(urls.get(i));
		}
		return Predicates.or(predicates);
	}

	public String title() {
		return "接口说明文档";
	}

	public String description() {
		return "详细说明(可覆盖父类方法)";
	}

	public String creater() {
		return "creater";
	}

	private ApiInfo apiInfo() {
		return new ApiInfoBuilder().title(title()).description(description())
				.termsOfServiceUrl("http://jz.gymchina.com").contact(new Contact(creater(), "", "")).build();
	}
}

==> tiny-swagger-0.0.1-20190102.072913-7-sources.jar: com/gymchina/tiny/swagger/SwaggerRegisterConfiguration.java <==
package com.gymchina.tiny.swagger;

import java.io.IOException;
import java.net.URISyntaxException;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.context.annotation.Bean;

import com.google.common.base.Predicate;
import com.google.common.base.Predicates;

import springfox.documentation.builders.ApiInfoBuilder;
import springfox.documentation.builders.PathSelectors;
import springfox.documentation.service.ApiInfo;
import springfox.documentation.spi.DocumentationType;
import springfox.documentation.spring.web.plugins.Docket;
import springfox.documentation.swagger2.annotations.EnableSwagger2;

/**
 * @Title SwaggerRegisterConfiguration
 * @Package com.gymchina.tiny.swagger
 * @author tangjunfeng
 * @date 2018年12月28日 下午4:15:21
 * @version V1.0
 */
@EnableSwagger2
public abstract class SwaggerRegisterConfiguration {

	private static Logger logger = LoggerFactory.getLogger(SwaggerRegisterConfiguration.class);

	@Bean
	public Docket petApi() throws ClassNotFoundException, IOException, URISyntaxException {
		logger.info("Loadding Swagger Interfaces Infomation [Title : {} , creater : {}]", title(), creater());
		return new Docket(DocumentationType.SWAGGER_2).groupName("full-api").apiInfo(apiInfo()).select()
				.paths(petstorePaths()).build().useDefaultResponseMessages(false);
	}

	public abstract String[] swaggerPackages();

	@SuppressWarnings("unchecked")
	public Predicate<String> petstorePaths() throws ClassNotFoundException, IOException, URISyntaxException {
		List<String> urls = DiscoverySwagger.discoveryMappingUrl(swaggerPackages());
		if (null == urls || urls.isEmpty())
			return Predicates.or();
		Predicate<String>[] predicates = new Predicate[urls.size()];
		for (int i = 0; i < urls.size(); i++) {
			predicates[i] = PathSelectors.regex(urls.get(i));
		}
		return Predicates.or(predicates);
	}

	public String title() {
		return "接口说明文档";
	}

	public String description() {
		return "详细说明(可覆盖父类方法)";
	}

	public String creater() {
		return "creater";
	}

	private ApiInfo apiInfo() {
		return new ApiInfoBuilder().title(title()).description(description())
				.termsOfServiceUrl("http://jz.gymchina.com").contact(creater()).build();
//		return new ApiInfoBuilder().title(title()).description(description())
//				.termsOfServiceUrl("http://jz.gymchina.com").contact(new Contact(creater(), "", "")).build();
	}
}
